fnss.topologies.topology.DirectedTopology.stacks — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »

# fnss.topologies.topology.DirectedTopology.stacks

`DirectedTopology.` `stacks`()

  Return a dictionary of all node stacks, keyed by node

  Returns : | stacks : dict A dictionary of all node stacks, keyed by node. Each node stack is a tuple (name, properties) where name is the stack name and properties is a the dictionary

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »